@@ -59,8 +59,11 @@ private:
 /* Settings Data */
 void NoteLinkingTest::initTestCase()
 {
-    m_md4qtParser.addTextPlugin(256, NoteLinkingPlugin::noteLinkingHelperFunc, true, {});
-    m_md4qtParser.addTextPlugin(1024, md4qtDataCleaner::dataCleaningFunc, false, {});
+    m_md4qtParser.addTextPlugin(static_cast<MD::TextPlugin>(static_cast<int>(MD::TextPlugin::UserDefined) + 1),
+                                NoteLinkingPlugin::noteLinkingHelperFunc,
+                                true,
+                                {});
+    m_md4qtParser.addTextPlugin(md4qtDataCleaner::dataCleanerId, md4qtDataCleaner::dataCleaningFunc, false, {});
 }
 
 /* TEST */
