@@ -21,15 +21,32 @@ namespace MD
 // Visitor
 //
 
-//! Visitor interface to walk through Document.
+/*!
+ * \class MD::Visitor
+ * \inmodule md4qt
+ * \inheaderfile md4qt/visitor.h
+ *
+ * \brief Visitor interface to walk through the MD::Document.
+ *
+ * This is a very basic implementation of walking through the document.
+ *
+ * \sa MD::details::AlgoVisitor, MD::details::HtmlVisitor, MD::PosCache.
+ */
 template<class Trait>
 class Visitor
 {
 public:
+    /*!
+     * Default constructor.
+     */
     Visitor() = default;
     virtual ~Visitor() = default;
 
-    //! Walk through the document.
+    /*!
+     * Walk through the document.
+     *
+     * \a d Markdown document.
+     */
     void process(std::shared_ptr<Document<Trait>> d)
     {
         m_anchors.clear();
@@ -95,42 +112,57 @@ public:
     }
 
 protected:
-    //! For some generator it's important to keep line endings like they were in Markdown.
-    //! So onParagraph() method invokes this method when necessary to add line ending.
+    /*!
+     * For some generator it's important to keep line endings like they were in Markdown.
+     * So onParagraph() method invokes this method when necessary to add line ending.
+     */
     virtual void onAddLineEnding() = 0;
 
-    //! Handle user-defined item.
-    virtual void onUserDefined(
-        //! Item.
-        Item<Trait> *item)
+    /*!
+     * Handle user-defined item.
+     *
+     * \a item Item.
+     */
+    virtual void onUserDefined(Item<Trait> *item)
     {
         MD_UNUSED(item)
     }
 
-    //! Handle text item.
-    virtual void onText(
-        //! Text.
-        Text<Trait> *t) = 0;
+    /*!
+     * Handle text item.
+     *
+     * \a t Text.
+     */
+    virtual void onText(Text<Trait> *t) = 0;
 
-    //! Handle LaTeX math expression.
-    virtual void onMath(
-        //! Math.
-        Math<Trait> *m) = 0;
+    /*!
+     * Handle LaTeX math expression.
+     *
+     * \a m Math.
+     */
+    virtual void onMath(Math<Trait> *m) = 0;
 
-    //! Handle line break.
-    virtual void onLineBreak(
-        //! Linebreak.
-        LineBreak<Trait> *b) = 0;
+    /*!
+     * Handle line break.
+     *
+     * \a b Line break.
+     */
+    virtual void onLineBreak(LineBreak<Trait> *b) = 0;
 
-    //! Handle paragraph.
-    virtual void onParagraph(
-        //! Paragraph.
-        Paragraph<Trait> *p,
-        //! Wrap this paragraph with something or no? It's useful to not wrap standalone
-        //! paragraph in list item, for example.
-        bool wrap)
+    /*!
+     * Handle paragraph.
+     *
+     * \a p Paragraph.
+     *
+     * \a wrap Wrap this paragraph with something or no? It's useful to not wrap standalone
+     *         paragraph in list item, for example.
+     *
+     * \a skipOpeningWrap Indicates that opening wrap should be added or no.
+     */
+    virtual void onParagraph(Paragraph<Trait> *p, bool wrap, bool skipOpeningWrap = false)
     {
         MD_UNUSED(wrap)
+        MD_UNUSED(skipOpeningWrap)
 
         long long int l = (!p->items().empty() ? p->items().at(0)->startLine() : -1);
 
@@ -184,25 +216,33 @@ protected:
         }
     }
 
-    //! Handle heading.
-    virtual void onHeading(
-        //! Heading.
-        Heading<Trait> *h) = 0;
+    /*!
+     * Handle heading.
+     *
+     * \a h Heading.
+     */
+    virtual void onHeading(Heading<Trait> *h) = 0;
 
-    //! Handle code.
-    virtual void onCode(
-        //! Code.
-        Code<Trait> *c) = 0;
+    /*!
+     * Handle code.
+     *
+     * \a c Code.
+     */
+    virtual void onCode(Code<Trait> *c) = 0;
 
-    //! Handle inline code.
-    virtual void onInlineCode(
-        //! Code.
-        Code<Trait> *c) = 0;
+    /*!
+     * Handle inline code.
+     *
+     * \a c Code
+     */
+    virtual void onInlineCode(Code<Trait> *c) = 0;
 
-    //! Handle blockquote.
-    virtual void onBlockquote(
-        //! Blockquote.
-        Blockquote<Trait> *b)
+    /*!
+     * Handle blockquote.
+     *
+     * \a b Blockquote.
+     */
+    virtual void onBlockquote(Blockquote<Trait> *b)
     {
         for (auto it = b->items().cbegin(), last = b->items().cend(); it != last; ++it) {
             if (static_cast<int>((*it)->type()) >= static_cast<int>(ItemType::UserDefined)) {
@@ -248,52 +288,72 @@ protected:
         }
     }
 
-    //! Handle list.
-    virtual void onList(
-        //! List.
-        List<Trait> *l) = 0;
+    /*!
+     * Handle list.
+     *
+     * \a l List.
+     */
+    virtual void onList(List<Trait> *l) = 0;
 
-    //! Handle table.
-    virtual void onTable(
-        //! Table.
-        Table<Trait> *t) = 0;
+    /*!
+     * Handle table.
+     *
+     * \a t Table.
+     */
+    virtual void onTable(Table<Trait> *t) = 0;
 
-    //! Handle anchor.
-    virtual void onAnchor(
-        //! Anchor.
-        Anchor<Trait> *a) = 0;
+    /*!
+     * Handle anchor.
+     *
+     * \a a Anchor.
+     */
+    virtual void onAnchor(Anchor<Trait> *a) = 0;
 
-    //! Handle raw HTML.
-    virtual void onRawHtml(
-        //! Raw HTML.
-        RawHtml<Trait> *h) = 0;
+    /*!
+     * Handle raw HTML.
+     *
+     * \a h Raw HTML.
+     */
+    virtual void onRawHtml(RawHtml<Trait> *h) = 0;
 
-    //! Handle horizontal line.
-    virtual void onHorizontalLine(
-        //! Horizontal line.
-        HorizontalLine<Trait> *l) = 0;
+    /*!
+     * Handle horizontal line.
+     *
+     * \a l Horizontal line.
+     */
+    virtual void onHorizontalLine(HorizontalLine<Trait> *l) = 0;
 
-    //! Handle link.
-    virtual void onLink(
-        //! Link.
-        Link<Trait> *l) = 0;
+    /*!
+     * Handle link.
+     *
+     * \a l Link.
+     */
+    virtual void onLink(Link<Trait> *l) = 0;
 
-    //! Handle image.
-    virtual void onImage(
-        //! Image.
-        Image<Trait> *i) = 0;
+    /*!
+     * Handle image.
+     *
+     * \a i Image.
+     */
+    virtual void onImage(Image<Trait> *i) = 0;
 
-    //! Handle footnote reference.
-    virtual void onFootnoteRef(
-        //! Footnote reference.
-        FootnoteRef<Trait> *ref) = 0;
+    /*!
+     * Handle footnote reference.
+     *
+     * \a ref Footnote reference.
+     */
+    virtual void onFootnoteRef(FootnoteRef<Trait> *ref) = 0;
 
-    //! Handle list item.
-    virtual void onListItem(
-        //! List item.
-        ListItem<Trait> *i,
-        //! Is this item first in the list?
-        bool first)
+    /*!
+     * Handle list item.
+     *
+     * \a i List item.
+     *
+     * \a first Is this item first in the list?
+     *
+     * \a skipOpeningWrap Indicates that opening wrap should be added or no.
+     */
+    virtual void onListItem(ListItem<Trait> *i, bool first, bool skipOpeningWrap = false)
     {
         MD_UNUSED(first)
 
@@ -307,7 +367,7 @@ protected:
                     break;
 
                 case ItemType::Paragraph:
-                    onParagraph(static_cast<Paragraph<Trait> *>(it->get()), (i->items().size() > 1 && i->items().at(1)->type() != ItemType::List));
+                    onParagraph(static_cast<Paragraph<Trait> *>(it->get()), wrapFirstParagraphInListItem(i), skipOpeningWrap);
                     break;
 
                 case ItemType::Code:
@@ -338,13 +398,17 @@ protected:
                     break;
                 }
             }
+
+            skipOpeningWrap = false;
         }
     }
 
-    //! Handle table cell.
-    virtual void onTableCell(
-        //! Table cell.
-        TableCell<Trait> *c)
+    /*!
+     * Handle table cell.
+     *
+     * \a c Table cell.
+     */
+    virtual void onTableCell(TableCell<Trait> *c)
     {
         for (auto it = c->items().cbegin(), last = c->items().cend(); it != last; ++it) {
             if (static_cast<int>((*it)->type()) >= static_cast<int>(ItemType::UserDefined)) {
@@ -385,10 +449,12 @@ protected:
         }
     }
 
-    //! Handle footnote.
-    virtual void onFootnote(
-        //! Footnote.
-        Footnote<Trait> *f)
+    /*!
+     * Handle footnote.
+     *
+     * \a f Footnote.
+     */
+    virtual void onFootnote(Footnote<Trait> *f)
     {
         for (auto it = f->items().cbegin(), last = f->items().cend(); it != last; ++it) {
             if (static_cast<int>((*it)->type()) >= static_cast<int>(ItemType::UserDefined)) {
@@ -434,10 +500,24 @@ protected:
         }
     }
 
+    /*!
+     * Returns whether first paragraph in list item should be wrapped.
+     *
+     * \a i List item.
+     */
+    virtual bool wrapFirstParagraphInListItem(ListItem<Trait> *i) const
+    {
+        return (i->items().size() > 1 && i->items().at(1)->type() != ItemType::List);
+    }
+
 protected:
-    //! All available m_anchors in the document.
+    /*!
+     * All available m_anchors in the document.
+     */
     typename Trait::template Vector<typename Trait::String> m_anchors;
-    //! Document.
+    /*!
+     * Document.
+     */
     std::shared_ptr<Document<Trait>> m_doc;
 }; // class Visitor
 
